@@ -53,7 +53,7 @@ class Configuration(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["ConfigurationProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[ConfigurationProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -264,7 +264,7 @@ class Namespace(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["NamespaceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[NamespaceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -359,7 +359,7 @@ class RosConfiguration(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosConfigurationProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosConfigurationProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -816,7 +816,7 @@ class RosNamespace(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosNamespaceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosNamespaceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
